# This file was auto-generated by Fern from our API Definition.

import enum


class MavenAGIEnvironment(enum.Enum):
    PRODUCTION = "https://www.mavenagi-apis.com"
    STAGING = "https://www.staging.mavenagi-apis.com"
