# This file was auto-generated by Fern from our API Definition.

from .translation_request import TranslationRequest
from .translation_response import TranslationResponse

__all__ = ["TranslationRequest", "TranslationResponse"]
