# This file was auto-generated by Fern from our API Definition.

import typing

ConversationField = typing.Union[
    typing.Literal[
        "Category",
        "FirstResponseTime",
        "HandleTime",
        "HumanAgents",
        "App",
        "Sentiment",
        "QualityReason",
        "ResolutionStatus",
        "Quality",
        "Users",
        "ResponseLength",
        "ThumbsUpCount",
        "ThumbsDownCount",
        "Tags",
        "UserMessageCount",
        "Languages",
        "Actions",
        "IncompleteActions",
        "Sources",
        "CreatedAt",
    ],
    typing.Any,
]
