# This file was auto-generated by Fern from our API Definition.

from .conversation_numeric_metric import ConversationNumericMetric
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class ConversationPercentile(ConversationNumericMetric):
    """
    Calculates specified percentile for a numeric field.
    """

    percentile: float = pydantic.Field()
    """
    The percentile to calculate. Example: 25 computes the 25th percentile.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
