# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .knowledge_base_version_type import KnowledgeBaseVersionType
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class KnowledgeBaseVersion(UniversalBaseModel):
    """
    Examples
    --------
    from mavenagi.knowledge import KnowledgeBaseVersion

    KnowledgeBaseVersion(
        type="FULL",
    )
    """

    type: KnowledgeBaseVersionType = pydantic.Field()
    """
    Indicates whether the completed version constitutes a full or partial refresh of the knowledge base. Deleting and updating documents is only supported for partial refreshes.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
