# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing_extensions
import typing
from .time_series import TimeSeries
from ...core.serialization import FieldMetadata
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class DateHistogramResponse(UniversalBaseModel):
    time_series: typing_extensions.Annotated[typing.List[TimeSeries], FieldMetadata(alias="timeSeries")] = (
        pydantic.Field()
    )
    """
    The dataset for the date histogram.
    Each series represents a separate plottable time series.
    Series names reflect the grouping field values.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
