# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .series import Series
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class BarChartResponse(UniversalBaseModel):
    series: typing.List[Series] = pydantic.Field()
    """
    Each LabeledPoint in the series represents a value for the bar, where the name serves as the bar's label.
    If vertical grouping is defined, multiple series will be created, each representing a group.
    In such cases, the bars can be stacked to reflect the grouped data distribution.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
