# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .app_user_identifier import AppUserIdentifier
import pydantic
from .user_data import UserData
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class AppUser(UniversalBaseModel):
    identifiers: typing.List[AppUserIdentifier] = pydantic.Field()
    """
    Used to determine whether two users from different apps are the same
    """

    data: typing.Dict[str, UserData]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
