# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from .knowledge_base_properties import KnowledgeBaseProperties
from ...commons.types.precondition_group import PreconditionGroup
import typing_extensions
from ...commons.types.entity_id_base import EntityIdBase
from ...core.serialization import FieldMetadata
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
from ...core.pydantic_utilities import update_forward_refs


class KnowledgeBaseRequest(KnowledgeBaseProperties):
    """
    Examples
    --------
    from mavenagi.commons import EntityIdBase
    from mavenagi.knowledge import KnowledgeBaseRequest

    KnowledgeBaseRequest(
        knowledge_base_id=EntityIdBase(
            reference_id="help-center",
        ),
        name="Help center",
        type="API",
    )
    """

    knowledge_base_id: typing_extensions.Annotated[EntityIdBase, FieldMetadata(alias="knowledgeBaseId")] = (
        pydantic.Field()
    )
    """
    ID that uniquely identifies this knowledge base
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(PreconditionGroup, KnowledgeBaseRequest=KnowledgeBaseRequest)
