# This file was auto-generated by Fern from our API Definition.

import typing

QualityReason = typing.Union[
    typing.Literal[
        "MISSING_KNOWLEDGE",
        "MISSING_USER_INFORMATION",
        "MISSING_ACTION",
        "NEEDS_USER_CLARIFICATION",
        "UNSUPPORTED_FORMAT",
        "GREAT_ANSWER",
        "INTERRUPTED",
        "UNSUPPORTED_USER_BEHAVIOR",
        "UNKNOWN",
    ],
    typing.Any,
]
